@@ -2,8 +2,9 @@
 #' effect of xk.
 #'
 #' This function uses data on two column vectors, xi, xj and 
-#' xk which can be a vector or a matrix usually of the remaining control
-#' variables. 
+#' xk which can be a vector or a matrix usually of the remaining 
+#' variables in the model including optional control
+#' variables. It removes missing data from input variables before proceeding.
 #'
 #' @param xi {Input vector of data for variable xi}
 #' @param xj {Input vector of data for variable xj}
@@ -11,6 +12,9 @@
 #' @return 
 #' \item{ouij}{Generalized partial correlation Xi with Xj (=cause) after removing xk}
 #' \item{ouji}{Generalized partial correlation Xj with Xi (=cause) after removing xk}
+#' allowing for control variables. 
+#' @author Prof. H. D. Vinod, Economics Dept., Fordham University, NY.
+#' @seealso See  \code{\link{parcor_linear}}.
 #' @note This function calls \code{\link{kern}}, 
 #' @examples 
 #' 
@@ -21,11 +25,16 @@
 #' }#' 
 #' @export
 
-parcor_ijk = function(xi, xj, xk) {
-  uik=kern(dep.y=xi,reg.x=xk,residuals=TRUE)$resid
-  ujk=kern(dep.y=xj,reg.x=xk,residuals=TRUE)$resid
-  sgn=sign(cor(uik,ujk))
-  ouij = sgn * kern(dep.y=uik, reg.x=ujk)$R2
-  ouji = sgn * kern(dep.y=ujk, reg.x=uik)$R2
+parcor_ijk =function (xi, xj, xk) 
+{
+  na2 = naTriplet(xi, xj, ctrl=xk)
+  xi = na2$newx
+  xj = na2$newy
+  xk = na2$newctrl
+  uik = kern(dep.y = xi, reg.x = xk, residuals = TRUE)$resid
+  ujk = kern(dep.y = xj, reg.x = xk, residuals = TRUE)$resid
+  sgn = sign(cor(uik, ujk))
+  ouij = sgn * kern(dep.y = uik, reg.x = ujk)$R2
+  ouji = sgn * kern(dep.y = ujk, reg.x = uik)$R2
   list(ouij = ouij, ouji = ouji)
 }
